@@ -53,7 +53,7 @@
 #define MOD_GM_COMMON_H
 
 /* constants */
-#define GM_VERSION                 "1.2.0"
+#define GM_VERSION                 "1.2.2"
 #define GM_ENABLED                      1
 #define GM_DISABLED                     0
 #define GM_BUFFERSIZE               98304
@@ -193,6 +193,8 @@ typedef struct mod_gm_opt_struct {
     int            do_hostchecks;                           /**< flag whether mod-gearman will process hostchecks at all */
     mod_gm_exp_t * exports[GM_NEBTYPESSIZE];                /**< list of exporter queues */
     int            exports_count;                           /**< number of export queues */
+    int            orphan_host_checks;                      /**< generate fake result for orphaned host checks */
+    int            orphan_service_checks;                   /**< generate fake result for orphaned service checks */
 /* worker */
     char         * identifier;                              /**< identifier for this worker */
     char         * pidfile;                                 /**< path to a pidfile */
