@@ -501,7 +501,7 @@ char *decode_xml(char *string) {
             { '<',  "&lt;"   },
             { '&',  "&amp;"  },
             { '\'', "&#039;" },
-            { '\|', "&#124;" },
+            { '|',  "&#124;" },
     };
     int i;
     char *found;
